#
# spec file for package vino
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vino
Version:        3.22.0
Release:        9.14
Summary:        GNOME VNC Server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            http://www.gnome.org
Source0:        https://download.gnome.org/sources/vino/3.22/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM vino-error-on-wayland.patch boo#1122549 mgorse@suse.com -- have vino-server print an error if wayland is detected, rather than segfaulting.
Patch0:         vino-error-on-wayland.patch
# PATCH-FIX-UPSTREAM vino-CVE-2019-15681.patch boo#1155419 mgorse@suse.com -- fix uninitialized memory read in LibVNCServer.
Patch1:         vino-CVE-2019-15681.patch

BuildRequires:  fdupes
BuildRequires:  intltool >= 0.50.0
BuildRequires:  libavahi-glib-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gnutls) >= 2.2.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0) >= 3.0.0
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(systemd)
# Disable telepathy support and pass --without-telepathy to configure
#BuildRequires:  pkgconfig(telepathy-glib) >= 0.18.0
BuildRequires:  pkgconfig(xtst)

%description
A VNC Server for GNOME

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--libexecdir=%{_libexecdir}/vino \
	--enable-ipv6 \
	--without-telepathy \
	--with-gnutls \
	--with-gcrypt \
	--with-avahi \
	--with-zlib \
	--with-jpeg \
	%{nil}
%make_build

%install
%make_install
rm %{buildroot}%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.Client.Vino.service
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_datadir}/applications/vino-server.desktop
#%%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.Client.Vino.service
%{_datadir}/glib-2.0/schemas/org.gnome.Vino.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.Vino.gschema.xml
# Disable telepathy support
#%%dir %%{_datadir}/telepathy/
#%%dir %%{_datadir}/telepathy/clients/
#%%{_datadir}/telepathy/clients/Vino.client
%{_libexecdir}/vino
%{_userunitdir}/vino-server.service

%files lang -f %{name}.lang

%changelog
* Thu Jan 13 2022 Michael Gorse <mgorse@suse.com>
- Remove telepathy dbus service, since we have telepathy disabled
  (boo#1177663).
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Nov 12 2019 Michael Gorse <mgorse@suse.com>
- Add vino-CVE-2019-15681.patch: fix uninitialized memory read in
  LibVNCServer (boo#1155419 CVE-2019-15681).
* Wed Jan 23 2019 mgorse@suse.com
- Add vino-error-on-wayland.patch: print an error if wayland is
  detected, rather than segfaulting (boo#1122549 bgo#761120).
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Phase out telepathy support in GNOME, mask
  pkgconfig(telepathy-glib) BuildRequires, and pass
  - -without-telepathy to configure.
* Mon Jul  9 2018 bjorn.lie@gmail.com
- Drop NetworkManager-devel BuildRequires and stop passing
  with-network-manager: No longer needed, nor recognized.
- Stop passing with-libnotify and with-gnome-keyring to configure,
  no longer recognized.
- Modernize spec, use autosetup and make_build macros.
- Drop glib2_gsettings_schema_requires macro and stop post(un)
  handling of glib2_gsettings_schema_post(un), no longer needed.
- Drop update-desktop-files BuildRequires and no longer use
  suse_update_desktop_file macro, no longer needed.
- Replace telepathy-glib-devel with pkgconfig(telepathy-glib)
  BuildRequires.
- Add explicit pkgconfig(dbus-glib-1), pkgconfig(gio-unix-2.0),
  pkgconfig(glib-2.0) and pkgconfig(gtk+-x11-3.0) BuildRequires:
  align with what configure checks for.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + No changes.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + build: Fix syntax error introduced in 27785a2.
  + build: Use AM_DISTCHECK_CONFIGURE_FLAGS.
  + server: Add a way for Vino to be started via user systemd.
  + Allow building on non-systemd systems.
  + Check for sm and ice in configure.
  + Remove unused --with-network-manager option.
  + Fix two memory leaks.
  + Updated translations.
- Add pkgconfig(systemd) BuildRequires, build the user systemd
  support.
* Thu May 26 2016 federico@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Avoid a crash when showing the preferences.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Improve handling of name resolution failure.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Stable release, no changes since 3.15.92.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Avoid a critical EggSMClient warning on startup.
  + Handle closed signal properly on notification prompt.
* Fri Feb 20 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + vino-upnp: Use GNetworkMonitor.
* Fri Feb 20 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Remove obsolete GSettings conversion file.
  + Fix Turkish desktop keywords translation.
  + Remove obsolete intltool scripts from Makefile.
  + Skip intermediate file with Automake 1.15.
  + Do not set obsolete PKG_NAME variable.
  + Updated translations.
* Fri Feb 20 2015 zaitor@opensuse.org
- Update to version 3.14.2:
  + Skip intermediate file with Automake 1.15.
  + Fix Turkish desktop keywords translation.
  + Handle closed signal properly on notification prompt.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Remove all HTTP server code.
  + Updated translations.
- no longer pass --enable-http-server=yes to configure: no longer
  available.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Get started by the g-s-d sharing plugin.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + libvncserver: fix non-literal format string issue.
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Remove vino-passwd.
  + Add dependencies on generated files (bgo#720956).
  + Move dbus code under server/ directory.
  + Updated translations.
- Clean up spec file a bit:
  + Remove duplicate libnotify-devel BuildRequires (it's present as
    pkgconfig(libnotify)).
  + Drop commands targetting openSUSE <= 11.3.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Remove dependency on libsoup.
  + Updated translations.
- Drop libsoup-devel BuildRequires: No longer needed.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix reading of TLS data to account for cached data.
  + Reject new clients if in the deferred state.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Move tube declaration to the right place.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Be more careful with memory allocation.
  + Remove preferences dialog (bgo#700070).
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fixed syntax in translation of Keywords string.
  + Back out "authentication-method" setting change.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Remove choices from authentication-methods setting.
  + Bugs fixed: bgo#668187.
  + Updated translations.
* Mon Mar  4 2013 zaitor@opensuse.org
- Update to version 3.7.91:
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Export whether the server is connected to through D-Bus.
  + server: Make libnotify a hard dependency.
  + Use notifications to prompt.
  + Don't show vino-preferences in GNOME.
  + Bring up the sharing panel when available.
  + Change schema path to standard format.
  + Updated translations.
- Add pkgconfig(libnotify) BuildRequires: new hard dependency.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Added keywords to .desktop file (bgo#691062).
  + Add "desktop-entry" notification hint (bgo#691045).
  + Updated translations.
* Mon Jan  7 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Consistently use SECRET_DEPS, not LIBSECRET_DEPS.
  + Update GSettings schema descriptions and summaries.
  + Do not leak clipboard to unauthenticated clients.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Fixups for -Wmissing-prototypes with miniupnp.
  + Set quality level if JPEG support is enabled.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Build fixes.
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Migrate from libgnome-keyring to libsecret
  + Updated translations.
- Replace libgnome-keyring-devel BuildRequires with
  pkgconfig(libsecret-1), following upstreams port to libsecret.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Depend on intltool 0.50 for GSettings translations
  + Use XFixes to provide RFB cursor image
  + Fix the cursor bounds computation
  + Fix iteration of the cursor->source[] array
  + Updated translations.
* Thu May 24 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Add --tube arg to launch vino in "tube only" mode.
  + Bugs fixed: bgo#651960, bgo#674707.
  + Updated translations.
* Mon May 21 2012 badshah400@gmail.com
- Use pkgconfig(gnutls) BuildRequires instead of gnutls-devel. This
  is more correct and helps avoid the issue with gnutls-devel
  having been removed from Factory.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Updated translations.
* Tue Feb 28 2012 fcrozat@suse.com
- Add missing pkgconfig(xtst) BuildRequires: it used to be
  automatically brought in before the xorg-x11 packaging changes.
- Add libjpeg-devel / libgcrypt-devel BuildRequires: those were
  missing, which meant we didn't have some important features.
- Add explicit switches to configure to ensure features are not
  lost by accident: --enable-ipv6 --with-telepathy --with-libnotify
  - -with-network-manager --with-gnome-keyring --with-gnutls
  - -with-gcrypt --with-avahi --with-zlib --with-jpeg.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(ice) and pkgconfig(sm) BuildRequires: they used to
  be pulled in by something else before.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add option to disable connect notifications
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Update smclient to latest libegg version.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix help links.
  + Updated translations.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Use new location for Mallard help (bgo#657927)
  + Make all targets use compiler warning flags
  + Updated translations.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Updated translations.
* Mon Aug 15 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Use GtkBox rather than GtkHBox or GtkVBox
  + Updated translations.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Add GConf to GSettings convert file, bgo#654901
  + Only call g_settings_sync() when necessary
  + Updated translations.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Add more categories to preferences desktop file
  + Use const instead of deprecated G_CONST_RETURN
  + Make desktop files appear in Unity too, bgo#653802
- Note that we still change the categories in
  vino-preferences.desktop, as the updated categories are still not
  what we want for our menu structure. However, append RemoteAccess
  and Network to the list, like upstream.
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Minor build fixes
  + Updated translations.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Improve description of UPnP feature, bgo#594521
  + Improve status icon tooltip string, bgo#594253
  + Update copyright information in about dialog
  + Do not use deprecated GnuTLS functions, bgo#648606
  + Use ‘Desktop Sharing’ rather than ‘Remote Desktop’
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 3.0.2:
  + Avoid out-of-bounds memory accesses (CVE-2011-0904,
    CVE-2011-0905).
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + bgo#617436: fix cursor update logic.
  + Only send a motion event when the pointer moved.
  + Bind both an IPv4 and an IPv6 socket.
  + Updated translations.
* Tue Apr 26 2011 vuntz@opensuse.org
- Drop now unneeded libunique-devel BuildRequires.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.99.5:
  + Use GSettings autostart condition
  + Updated translations
- Changes from version 2.99.4:
  + Remove some unnecessary code in the capplet
  + Generate enums and marshalers before they are used
  + Remove server reachability message from the UI
  + Workaround that addresses CVE-2011-1164.
  + Build fixes.
  + Updated translations.
- Changes from version 2.99.3:
  + Overhaul build system.
  + Updated translations.
- Changes from version 2.99.2:
  + Added back telepathy functionality.
  + Added DISTCHECK_CONFIGURE_FLAGS to Makefile.am.
- Changes from version 2.99.1:
  + Added back basic mdns functionality.
  + Fixed typo in configure.in
- Changes from version 2.99.0:
  + Port to Gtk3
  + Port to GSettings
  + Port to GtkApplication
  + Port to GDBus
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Change old-style BuildRequires to new pkgconfig()/GNOME3 ones:
  gconf2-devel, gtk2-devel to pkgconfg(gtk+-3.0).
- Remove --enable-avahi/--enable-gnome-keyring configure options
  as they are default.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Thu Dec 23 2010 vuntz@opensuse.org
- Update to version 2.32.1:
  + Be compatible with old (< 0.7.0) and new (>= 0.7.0) libnotify
  + Updated translations.
* Thu Nov 11 2010 coolo@novell.com
- Own parent directories for telepathy.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Mon Sep  6 2010 vuntz@opensuse.org
- Make vino-preferences.desktop appear where it should in the menu,
  by replacing the categories: X-GNOME-NetworkSettings needs to be
  removed, and we want X-GNOME-PersonalSettings
- Use Productivity/Networking/Other rpm group instead of
  non-existing Productivity/Networking/Remote Desktop.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + Updated translations.
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + Improvements on Telepathy tubes stuff
  + Various internal work on replacing deprecated stuff
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.28.2:
  + Check if mDNS is active before asking for a local hostname.
  + Updated translations.
- Remove en@shaw translations on 11.2 and earlier.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Fix build in OpenBSD
  + Don't use restart feature of session manager
  + Updated translations.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Mon Sep  7 2009 dimstar@opensuse.org
- Update to version 2.27.92:
  + Fix a regression that allows more than one instance of the
    server to run.
  + Use vino's debug framework instead of g_printerr (mainly in
    tube code).
  + Make Avahi use the network interface defined in vino
    preferences.
  + Use integer (instead of double) as the port parameter in dbus
    calls (This fix 'localhost' appearing in preferences applet).
  + Fixed a warning in libgcrypt initialization.
  + Updated translations.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + (vino-passwd): Do not crash if a GConf server is not available.
  + Improvements in Telepathy tubes
  + Updated translations.
* Tue Aug 11 2009 dominique-obs@leuenberger.net
- Update to version 2.27.90:
  + Minor fixes
  + Updated translations.
- Drop vino-linking-order.patch and affilated BuildRequires and
  gnome-autogen.sh call.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Added an (GConf) option to disable XDamage extension. See
    bgo#533613.
  + Added Telepathy tubes support, allowing you to share the
    desktop with an IM buddy.
  + Dropped libgnome dependency. Using EggSmClient.
  + Migrate from libglade to GtkBuilder.
  + Many small bug fixes.
  + Updated translations.
- Use libexecdir.
- Drop libglade2-devel, libgnomeui-devel BuildRequires.
- Add gnome-keyring-devel, telepathy-glib-devel BuildRequires.
- Add vino-linking-order.patch to fix build.
* Tue May 19 2009 vuntz@novell.com
- Update to version 2.26.2:
  + bgo#581204, Use g_timeout_add_seconds
  + bgo#582843, Fix build in FreeBSD
  + bgo#533613, Added an option to disable XDamage extension. In
    some environments the XDamage extension does not work properly
    on 3D desktops. This adds a boolean gconf key
    'disable_xdamage'. If it is set to TRUE, Vino will not use it.
  + Minor tweaks.
  + Updated translations.
* Sun May  3 2009 mboman@suse.de
- Change BuildRequires from unique-devel to libunique-devel
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + bgo#575860 – Regenerating autotools always tries to compile
    local libifaddr.
  + Updated translations.
* Tue Mar 17 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
* Mon Mar  2 2009 mboman@suse.de
- Update to version 2.25.92:
  + Added dependency on NetworkManager for monitoring when network
    state changes. New configure flag: --enable-network-manager.
    If not set, enable it anyway if NM libraries are found
  + bgo#330691 – show .local hostname if avahi is present
  + Translation updates
- Remove BuildRequires gnome-common, scrollkeeper,
  gnome-keyring-devel
- Add new Buildrequirement NetworkManager-devel
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.25.91:
  + Install autostart file in $sysconfdir/xgd/autostart
    Usually you should pass the argument --sysconfdir=/etc to
    configure (or autogen.sh) script
  + i18n related fixes
  + Minor fixes
  + Translation updates
* Tue Feb  3 2009 mboman@suse.de
- Update to version 2.25.90:
  + Only show notification if the status icon is visible.
  + Fix drawing issues in the connectivity label.
  + Uses a file containing links to webservices, instead of
    use a hard coded one.
  + Shows an IP address instead of the local hostname in the
    connectivity label.
  + Translation updates
- Remove vino-bgo568646-fix-typo.patch. Fixed upstream
* Thu Jan 29 2009 vuntz@novell.com
- Update BuildRequires:
  + remove gnome-desktop-devel, gtk-doc, libidl-devel, sharutils
  + add gconf2-devel, gtk2-devel, unique-devel
* Thu Jan 29 2009 lmedinas@gmail.com
- Update to version 2.25.5:
  + New capplet
  + Translation updates
- Add libsoup-devel dependency
- Add vino-bgo568646-fix-typo.patch to fix typo
* Fri Jan 23 2009 vuntz@novell.com
- Add missing BuildRequires on libgnomeui-devel.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.25.4:
  + Added UPnP support. Created a new boolean gconf key called use_upnp
    For now, no GUI changes
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Removed local_only preference, and allow you to specify the network
    interface to listen.
  + Some minor fixes
  + Translation updates
* Tue Oct 21 2008 mboman@suse.de
- Update to version 2.24.1:
  + bgo#555105: Propagates port changes via avahi.
  + Update label in vino-preferences when the port changes.
  + bgo#161180: Hopefully fix an window empty bug.
  + lp#266932: Only restore the wallpaper when the last
    client disconnects.
  + Translation updates
* Fri Oct 10 2008 mboman@suse.de
- Enable gconf and http server
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates
* Tue Sep  9 2008 maw@suse.de
- Update to version 2.23.92:
  + Add an icon to the session desktop file
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Dropped bonobo activation. Vino is controlled by gnome-session.
  + Made vino-server a gnome-session client, still using libgnomeui.
  + The directory session/ is now obsolete.
  + Returns gboolean instead of void. Returns FALSE if there is another
    instance running.
  + Don't use bonobo shell function.
* Sat Aug 30 2008 mboman@novell.com
- Update to version 2.23.90:
  + Added the ability to hide the background on connections.
  + New compile-time option (--enable-libunique), allows only one
    instance of capplet running.
  + Added vino-server.desktop file required by new gnome-session.
  + Get rid of libgnome[ui] in the capplet.
  + Minor bug fixes
  + Translations
* Sat Aug  2 2008 captain.magnus@opensuse.org
- Update to version 2.23.5:
  + New command-line tool, vino-passwd, which allows you to change
  vino password. Similar to Unix passwd command. (Jorge Pereira)
  + Bug bgo#534262 - cyclic clipboard propagation (Jonh Wendell)
  + Minor bug fixes
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.22.2:
  + Bug fixed: bgo#534262.
* Fri Apr 11 2008 vuntz@suse.de
- Update to version 2.22.1:
  + Don't lock the screen in fake connections
  + Updated translations.
- Stop abusing the /usr/lib/gnome-panel/ and use /usr/lib/vino
- Change libidl build-requires to libidl-devel
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Updated translations.
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.92:
  + Fix some crashes
  + Build against recent glibcs
  + Updated translations.
* Wed Feb 20 2008 maw@suse.de
- Update to version 2.21.91:
  + Updated translations.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.90:
  + Updated translations.
* Thu Dec 13 2007 jpr@suse.de
- Update to 2.21.3
    + New gconf key to control the status icon behaviour
    + Added more options in the configuration applet
    + Handles clipboard copy and paste
    + Don't ship icons/ directory anymore
    + Fixes some key presses issues
    + Only show 'disconnect all' popup item in status icon if we have
    more than one client connected
    + Better handles disconnection from avahi-daemon
    + Minor fixes
  + Update Translations
* Thu Dec 13 2007 jpr@suse.de
- Update to 2.20.1
  + Update Translations
- enable avahi support with configure
- enable notify support
- remove vino-desktop.patch, %%suse_update_desktop_file will do the
  same thing
* Thu Oct 11 2007 sbrabec@suse.cz
- Use correct binding specific avahi package instead of
  mDNSResponder.
* Mon Sep 17 2007 gekker@suse.de
- Update to version 2.20.0
  + Update Translations.
* Mon Sep 10 2007 maw@suse.de
- Update to version 2.19.92:
  + Bugs (bugzilla.gnome.org) fixed: #353304 and #383147
  + Updated translations.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.90:
  + Include hostname in Avahi service name
  + Show the configure summary
  + Minor fixes
  + Updated translations.
* Fri Aug 10 2007 coolo@suse.de
- use %%version after the definition of Version
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- Use %%fdupes.
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.5
- New features: Show http server address in vino-preferences if
  it's compiled with http support; new configuration option
  (gconf key) 'lock_screen_on_disconnect', and builds against
  libnotify if it's available
- Bugs (bugzilla.gnome.org) fixed: #330690, #450074, #445525,
  [#440429], #436460, and #431627
- Updated translations.
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Wed May  9 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequieres [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Thu Apr 12 2007 maw@suse.de
- Update to version 2.18.1
- Bug fixes (all bug numbers are on bugzilla.gnome.org):
  + Fix the non-XDAMAGE, non-XSHM support, bug #423887 (Mark)
  + Fix crash on vino_input_init(), bug #425863 (Jonh, Mark)
  + Fix crashes on critical warning in vino-preferences applet,
    bug #418836 and bug #423027 (Halton Huo, Jonh)
- Updated translations for the da, es, eu, and gl locales.
* Mon Apr  9 2007 maw@suse.de
- Update to version 2.18.0
- Fixes for bugzilla.gnome.org #414905, #412559, #394005, #394462,
  [#357778], #400260, #391850, #394523, and #391848.
* Fri Mar  9 2007 maw@suse.de
- Remove the removal of the po/no stuff.
* Fri Mar  9 2007 maw@suse.de
- Update to version 2.17.5
    + Add D-Bus support so that capplet can find out the port number
    from the server (Jonh, Mark)
    + Display a notification bubble when someone connects if we
    haven't already prompted the user for authorization (Jonh, Mark)
    + Replace deprecated GnomeIconTheme usage with GtkIconTheme (Christian Persch)
    + Don't mark GObject property descriptions for translation (Mark)
    + Add a status icon allowing you to disconnect users
    (Jonh Wendell, Christian Persch, Mark, Calum, Andre Klapper)
    + Hide the help button in the prompt dialog (Mark)
    + Fix broken keyboard under Xsun (Halton Huo, Mark)
    + Fix the desktop name remoted to the client (Jonh Wendell)
    + Fix the stringification of the client hostname (Jonh Wendell)
    + Add "local_only" GConf key for use with SSH tunnels (Mark, Shaya Potter)
    + Add "alternative_port" GConf key (Mark, John Wendell)
    + Add ability to use gnome-keyring to store VNC password (Mark, Steven Zhang)
    + Add IPv6 support (Mark, Srirama Sharma)
    + Update for RFB 3.8 (Dan Winship)
    + Fix for X servers which don't support XShm (Dan Winship)
    + Fix CoRRE encoding problem (Mark)
    + Back-port some fixes from upstream libvncserver (Mark)
    + Add GTK category to .desktop file (Mark)
    + Mark some weird glade strings as non-translatable (Mark)
    + Fix icons not changing when icon theme changes (Mark)
    + Use glib's base64 functions instead of our own (Mark)
    + Use GtkLinkButton instead of VinoURL (Mariano Suárez-Alvarez)
    + Fix hang on wrong login (Gary Coady)
- Remove upstreamed vino-xgl.patch.
* Mon Feb  5 2007 sbrabec@suse.cz
- Fixed Categories.
* Fri Jan 12 2007 sbrabec@suse.cz
- Spec file cleanup.
* Mon Dec 18 2006 maw@suse.de
- Move to /usr.
* Fri Aug  4 2006 jhargadon@suse.de
- update to version 2.13.5
- Publish services over mDNS
- Fix keyboard brokeness with some X server configurations
- Fix crash with unicode mapped keysyms
- Added translations
* Thu May 11 2006 danw@suse.de
- Add fallback code so this still works if the X server doesn't
  support XShm shared pixmaps (eg, Xgl). #173173
* Thu Apr 13 2006 sbrabec@suse.cz
- Call %%suse_update_desktop_file.
- Use new control-center Categories instead of old ones.
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Sat Feb 25 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 rodrigo@suse.de
- Added vino-desktop.patch (#131371)
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.12.0.
* Thu Aug 25 2005 gekker@suse.de
- Update to version 2.11.92
* Tue Aug  2 2005 sbrabec@suse.cz
- Updated to version 2.11.90.
* Wed Jun 22 2005 gekker@suse.de
- Update to version 2.11.1.2
* Thu Mar 10 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Mon Jan 24 2005 ro@suse.de
- fix build on lib64
* Fri Jan 21 2005 clahey@suse.de
- Initial import.
